## cdist-type__issue(7)

### Nico Schottelius

`<nico-cdist--@--schottelius.org>`

## 1. NAME

cdist-type__issue - Manage issue

## 2. DESCRIPTION

This cdist type allows you to easily setup /etc/issue.

## 3. REQUIRED PARAMETERS

None.

## 4. OPTIONAL PARAMETERS

source
  If supplied, use this file as /etc/issue instead of default.

## 5. EXAMPLES

    __issue

    # When called from another type
    __issue --source "$__type/files/myfancyissue"

## 6. SEE ALSO

- cdist-type(7)

## 7. COPYING

Copyright (C) 2011 Nico Schottelius. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).